[![Radiant MLHub Logo](https://radiant-assets.s3-us-west-2.amazonaws.com/PrimaryRadiantMLHubLogo.png)](https://mlhub.earth/)

# Radiant MLHub Python Client

[![Unit tests](https://github.com/radiantearth/radiant-mlhub/workflows/Unit%20tests/badge.svg)](https://github.com/radiantearth/radiant-mlhub/actions)
[![Documentation](https://readthedocs.org/projects/radiant-mlhub/badge/)](https://radiant-mlhub.readthedocs.io/en/latest/)
[![PyPI version](https://badge.fury.io/py/radiant-mlhub.svg)](https://pypi.org/project/radiant-mlhub/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/radiant-mlhub)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/radiantearth/radiant-mlhub/main?filepath=examples%2Findex.ipynb)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.0-4baaaa.svg)](code_of_conduct.md)

*A Python client for the [Radiant MLHub API](https://mlhub.earth/).*

## Documentation

API reference and Getting Started guides are available on [Read the Docs](https://radiant-mlhub.readthedocs.io/en/latest/).

## Design Decisions

Major architectural and design decisions are documented using [Architectural Design Records](https://cognitect.com/blog/2011/11/15/documenting-architecture-decisions) stored in the [`docs/adr`](./docs/adr) directory.

## Contributing

See the [Contributing](./CONTRIBUTING.md) docs for details on contributing to the project.
